@@ -14,6 +14,46 @@ import commands
 import os
 import khteditor
 
+LANGUAGES = (('.R','R'),
+            ('.ada','ada'),
+            ('.c','c'),
+            ('.changelog','changelog'),
+            ('.cpp','cpp'),
+            ('.csharp','csharp'),
+            ('.desktop','desktop'),
+            ('.css','css'),
+            ('.diff','diff'),
+            ('.fort','fortran'),
+            ('.gtkrc','gtkrc'),
+            ('.haskell','haskell'),
+            ('.html','html'),
+            ('.idl','idl'),
+            ('.ini','ini'),
+            ('.java','java'),
+            ('.js','javascript'),
+            ('.tex','latex'),
+            ('.lua','lua'),
+            ('makefile','makefile'),
+            ('markdown','markdown'),
+            ('.msil','msil'),
+            ('nemerle','nemerle'),
+            ('octave','octave'),
+            ('.pas','pascal'),
+            ('.pl','perl'),
+            ('.php','php'),
+            ('.po','po'),
+            ('.py','python'),
+            ('.rb','ruby'),
+            ('.scheme','scheme'),
+            ('.sh','sh'),
+            ('.tcl','tcl'),
+            ('texinfo','texinfo'),
+            ('.txt','None'),
+            ('.vb','vbnet'),
+            ('verilog','verilog'),
+            ('vhdl','vhdl'),
+            ('.xml','xml'),
+            )
 class FindAndReplaceDlg(QtGui.QDialog):
     """ Find and replace dialog """
     def __init__(self, parent=None):
@@ -204,31 +244,37 @@ class Window(QtGui.QMainWindow):
         filename = self.editor.filename
         language = self.detectLanguage(filename)
         #Return None if language not yet implemented natively in KhtEditor
-        if (language != None):
-            exec 'from syntax.'+language+'_highlighter import Highlighter'
+        if language == 'python':
+            from syntax.python_highlighter import Highlighter
             self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,True)
             QtGui.QApplication.processEvents()
             self.highlighter = Highlighter(self.editor.document())
-            print 'test'
             QtGui.QApplication.processEvents()
             self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,False)
+        elif language != None:
+            from syntax.generic_highlighter import Highlighter
+            self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,True)
+            QtGui.QApplication.processEvents()
+            self.highlighter = Highlighter(self.editor.document(),language)
+            QtGui.QApplication.processEvents()
+            self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,False)            
         else:
             self.loadGenericHighlighter(filename)
 
     def loadGenericHighlighter(self,filename):
-        import highlighter
+        from syntax import pygments_highlighter
         #self.language = self.detectLanguage(filename)
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,True)
         QtGui.QApplication.processEvents()
-        self.highlighter = highlighter.Highlighter(self.editor.document(),str(filename))
+        self.highlighter = pygment_highlighter.Highlighter(self.editor.document(),str(filename))
         QtGui.QApplication.processEvents()
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,False)
     
     def detectLanguage(self,filename):
-        if (filename.endsWith('.py')) or (filename.endsWith('.py')):
-            return 'python'
-        else:
-            return None
+        for extension,lang in LANGUAGES:
+            if filename.endsWith(extension.lower()):
+                 return lang
+        return None
             
         return language
         
